@@ -47,13 +47,6 @@
 
 #include "common/spi-dbus.h"
 
-/*
- * Provides the path for the introspection directory.
- */
-#if !defined ATSPI_INTROSPECTION_PATH
-#error "No introspection XML directory defined"
-#endif
-
 /*---------------------------------------------------------------------------*/
 
 SpiBridge *spi_global_app_data = NULL;
@@ -302,7 +295,7 @@ socket_embed_hook (AtkSocket * socket, gchar * plug_id)
     {
       DBusMessage *message;
       *(plug_path++) = '\0';
-      message = dbus_message_new_method_call (plug_name, plug_path, "org.freedesktop.atspi.Accessible", "Embedded");
+      message = dbus_message_new_method_call (plug_name, plug_path, "org.a11y.atspi.Accessible", "Embedded");
       dbus_message_append_args (message, DBUS_TYPE_STRING, &path, DBUS_TYPE_INVALID);
       dbus_connection_send (spi_global_app_data->bus, message, NULL);
     }
@@ -414,20 +407,15 @@ adaptor_init (gint * argc, gchar ** argv[])
   spi_global_leasing  = g_object_new (SPI_LEASING_TYPE, NULL);
   spi_global_cache    = g_object_new (SPI_CACHE_TYPE, NULL);
 
-  /* Get D-Bus introspection directory */
-  introspection_directory = (char *) g_getenv ("ATSPI_INTROSPECTION_PATH");
-  if (introspection_directory == NULL)
-    introspection_directory = ATSPI_INTROSPECTION_PATH;
-
   /* Register droute for routing AT-SPI messages */
   spi_global_app_data->droute =
-    droute_new (spi_global_app_data->bus, introspection_directory);
+    droute_new (spi_global_app_data->bus);
 
   treepath = droute_add_one (spi_global_app_data->droute,
                              "/org/at_spi/cache", spi_global_cache);
 
   accpath = droute_add_many (spi_global_app_data->droute,
-                             "/org/freedesktop/atspi/accessible",
+                             "/org/a11y/atspi/accessible",
                              NULL,
                              (DRouteGetDatumFunction)
                              spi_global_register_path_to_object);
